

*To Check the Randomization

** Code to calculate the changes in proxy dates between 2006 and 2007

split prox06, generate(Proxlast)
rename Proxlast1 Proxlast_Mo
rename Proxlast2 Proxlast_Day
rename Proxlast3 Proxlast_Yr
gen prox_diff=proxy-365-proxy2006
replace prox_diff=. if Proxlast_Yr !="2006"
**Needed to drop the cases with no 2006 proxy in the database
gen prox_diff_abs=abs(prox_diff)
summarize prox_diff_abs, detail
**to give mean and median date changes in days

** To check for pretreatment comprability using the Audit Report Data

ttest arwordcount, by(group)
ttest arreadabilityrating, by(group)
sdtest arwordcount, by(group)




**CREATE THE INDUSTRY (SIC CODE) AND CONSULTANT CONTROL VARIABLES


*generate 1 D SIC group
egen sic1d=cut (sic), at(1000,2000,3000,4000,5000,6000,7000,8000,9000,10000)


*generate 2 D SIC group
egen twodig_sic=cut (sic), at(0700,1000,1500,2000,4000,5000,5200,6000,7000,9900)
label define SIC 1000 "Mineral Industries" 
label define SIC 1500 "Construction", add
label define SIC 2000 "Manufacturing", add
label define SIC 4000 "Trans/Communication/Utilities", add
label define SIC 5000 "Wholesale Trade", add
label define SIC 5200 "Retail Trade", add
label define SIC 6000 "Finance/RealEstate/Insurance", add
label define SIC 7000 "Service Industries", add
label values twodig_sic SIC

**PUT SOME OF THE SMALLER CATEGORIES INTO ``OTHER''

gen twodig_sic2 = twodig_sic
replace twodig_sic2=0 if twodig_sic==1000 |twodig_sic==5000 | twodig_sic==1500
label define SIC 0 "Other", add
label values twodig_sic2 SIC



*CREATE CONSULTANT variable 
gen consul=0
label define Consultant 0 "NA"
replace consul=7 if consultant !=""
label define Consultant 7 "Other", add
replace consul=1 if consultant =="Cook"
label define Consultant 1 "Cook", add
replace consul=2 if consultant =="Hewitt"
label define Consultant 2 "Hewitt", add
replace consul=3 if consultant =="Mercer"
label define Consultant 3 "Mercer", add
replace consul=4 if consultant =="Pearl Meyer"
label define Consultant 4 "Pearl Meyer", add
replace consul=5 if consultant =="Towers Perrin"
label define Consultant 5 "Towers Perrin", add
replace consul=6 if consultant =="Watson Wyatt"
label define Consultant 6 "Watson Wyatt", add
replace consul=8 if consultant =="None"
label define Consultant 8 "None", add
label values consul Consultant

**CONDENSE VARIABLE BY MOVING PEARL MEYER AND WATSON WYATT TO OTHER
gen consul_small=consul
replace consul_small=7 if consul==4 | consul==6
label values consul_small Consultant
**** Note in writeup that Pearl Meyer and Watson Wyatt moved to "other"



******ANALYSIS OF ANNUAL BONUS DISCLOSURE

** bar charts for annual bonuses -- uses catplot package

label define Process 0 "No Information"
label define Process 1 "Little Information", add
label define Process 2 "Some Information", add
label define Process 3 "Best Information", add
label values process Process

catplot group process, percent(group) recast(bar)  asyvars title ("Bonus Process")

label define Justification 0 "No Justification"
label define Justification 1 "Justification", add
label values justification Justification

catplot  group justification, percent(group) recast(bar)  asyvars title ("Bonus Justification")

label define Implementation 0 "No Implementation"
label define Implementation 1 "Some Implementation", add
label define Implementation 2 "Most Implementation", add
label values implementation Implementation

catplot group implementation, percent(group) recast(bar)  asyvars title ("Bonus Implementation")

label define Clarity 0 "Least Clear"
label define Clarity 1 "Medium Clear", add
label define Clarity 2 "Most Clear", add
label values generalclarity Clarity

catplot group generalclarity, percent(group) recast(bar)  asyvars title ("Bonus Clarity")



** probit models for annual bonus analyses -- uses Spost package -- All findings in Same Table in Paper
* Spost installation directions can be found here: http://www.indiana.edu/~jslsoc/web_spost/sp_install.htm

* generate wordcout and logged market cap controls
gen wc_1000 = wordcount/1000
gen log_cap = log(marketcap)

*Process Model
xi: oprobit process i.group i.consul_small i.twodig_sic2 log_cap wc_1000
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff



*Implementation Model
xi: oprobit implementation i.group i.consul_small i.twodig_sic2 log_cap wc_1000
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff



**Justification Model
xi: probit justification i.group i.consul_small i.twodig_sic2 log_cap wc_1000
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff

**General Clarity Model
xi: oprobit generalclarity i.group i.consul_small i.twodig_sic2 log_cap wc_1000
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff




**Because the Group-One Proxy Dates are closer together than Group Twos and we want to see the density on the same scale on the scatter plot we need to mess with the date variables a bit to generate the scatter plot.
**These lines of code do this by converting the dates into numbers and then essentially subtracting days from the later firms in Group two such that the group two X axis comprises essentially the same number of "days" as the group one x-axis



* generate condensed second group for figures
split proxydate, generate(Prox)
rename Prox1 Prox_Mo
rename Prox2 Prox_Day
rename Prox3 Prox_Yr
gen proxyplot=proxy
replace Prox_Day = subinstr(Prox_Day, "," , " ", .)
destring Prox_Day, replace
replace proxyplot=proxyplot-45 if Prox_Mo=="July"

replace proxyplot=proxyplot-30 if Prox_Mo=="June" & Prox_Day<16
replace proxyplot=proxyplot-45 if Prox_Mo=="June" & Prox_Day>15
replace proxyplot=proxyplot-10 if Prox_Mo=="May" & Prox_Day>15
replace proxyplot=proxyplot+30 if Prox_Mo=="January"
format proxyplot %tdMon_DD,_CCYY


***** Wordcount analysis

by group, sort : egen float wordcount_p25= pctile(wordcount), p(25)
by group, sort : egen float wordcount_p75= pctile(wordcount), p(75)
by group, sort : egen float wordcount_p40= pctile(wordcount), p(40)
by group, sort : egen float wordcount_p60= pctile(wordcount), p(60)
by group, sort : egen float wordcount_p10= pctile(wordcount), p(10)
by group, sort : egen float wordcount_p90= pctile(wordcount), p(90)
by group, sort : egen float wordcount_p33= pctile(wordcount), p(33)
by group, sort : egen float wordcount_p67= pctile(wordcount), p(67)
by group, sort : egen float wordcount_p45= pctile(wordcount), p(45)
by group, sort : egen float wordcount_p55= pctile(wordcount), p(55)

gen wordcount_1090=wordcount_p90-wordcount_p10
gen wordcount_2575=wordcount_p75-wordcount_p25
gen wordcount_3367=wordcount_p67-wordcount_p33
gen wordcount_4555=wordcount_p55-wordcount_p45

tabstat wordcount, statistics( mean median sd min max count cv range ) by(group) columns(statistics)
tabstat wordcount_p10 wordcount_p90 wordcount_1090 wordcount_p25 wordcount_p75 wordcount_2575 wordcount_p33 wordcount_p67 wordcount_3367 wordcount_p45 wordcount_p55 wordcount_4555, statistics( mean ) by(group) columns(variables)
ttest wordcount, by(group)
median wordcount, by(group)
sdtest wordcount, by(group)
robvar wordcount, by(group)


drop(wordcount_1090 wordcount_2575 wordcount_3367 wordcount_4555)

robvar wordcount, by(group)

** Generate condensed Word Count Scatter Plots with 3rd quintile and inter quartile ranges
twoway (scatter wordcount proxyplot, mcolor(gs12) msize(small)) (rarea wordcount_p40 wordcount_p60 proxyplot, fcolor(none) lcolor(black) lwidth(medium) cmissing(n)) (rarea wordcount_p25 wordcount_p75 proxyplot, fcolor(none) lcolor(gs9) lwidth(medium) lpattern(dash) cmissing(y)), ytitle(Word Count) ytitle(, orientation(vertical) margin(small)) ylabel(, labsize(small) angle(horizontal)) xtitle(Proxy Date (group two condensed)) xtitle(, margin(medsmall)) xlabel(#5, labsize(small)) legend(off)
tabstat wordcount, statistics( mean median sd min max count cv range ) by(group) columns(statistics)

* Generate wordcount histogram
histogram wordcount, width(750) start(0) percent fcolor(ltbluishgray) lcolor(blue) ylabel(, angle(horizontal) format(%9.0g)) xlabel(0(2500)15000) by(group, cols(1) iyaxes ixaxes ixtick ixlabel)


** SOME ROBUSTNESS / ALTERNATIVE EXPLANATION CHECKS

*WEB APPENDIX FIGURES CONCENING CONCENTRATION OF CONSULTANTS AND INDUSTRIES BY GROUP (ALSO MENTIONED IN TEXT)

*CONSULTANT DISTRIBUTIONS

gen consul_graph=consul
replace consul_graph=. if consul==0
replace consul_graph=. if consul==7
label values consul_graph Consultant

catplot consul_graph, recast(bar) ylabel(, angle(h)) by(group, cols(1)) percent(group) var1opts(sort(1) descending)

*Industry Distributions
catplot twodig_sic2, recast(bar) ylabel(, angle(h)) by(group, cols(1)) percent(group) var1opts(sort(1) descending)

**wordcount by group by consultant
graph bar (mean) wordcount, over(group) over(consul_graph, label(angle(stdarrow) labsize(small))) bar(1, fcolor(ltbluishgray)) bar(2, fcolor(ltbluishgray)) ylabel(, labsize(small) )


**Wordcount by group by industry
graph bar (mean) wordcount, over(group) over(twodig_sic2, label(angle(stdarrow) labsize(small))) bar(1, fcolor(ltbluishgray)) bar(2, fcolor(ltbluishgray)) ylabel(, labsize(small) angle(horizontal))



*********Readability analysis -- Mentioned in Text - Figures in Appendix -- Mirrors Word Count Analysis
replace averagereadability=sentences if wordcount !=. & averagereadability == .

by group, sort : egen float averagereadability_p25= pctile(averagereadability), p(25)
by group, sort : egen float averagereadability_p75= pctile(averagereadability), p(75)
by group, sort : egen float averagereadability_p40= pctile(averagereadability), p(40)
by group, sort : egen float averagereadability_p60= pctile(averagereadability), p(60)
by group, sort : egen float averagereadability_p10= pctile(averagereadability), p(10)
by group, sort : egen float averagereadability_p90= pctile(averagereadability), p(90)
by group, sort : egen float averagereadability_p33= pctile(averagereadability), p(33)
by group, sort : egen float averagereadability_p67= pctile(averagereadability), p(67)
by group, sort : egen float averagereadability_p45= pctile(averagereadability), p(45)
by group, sort : egen float averagereadability_p55= pctile(averagereadability), p(55)

gen averagereadability_1090=averagereadability_p90-averagereadability_p10
gen averagereadability_2575=averagereadability_p75-averagereadability_p25
gen averagereadability_3367=averagereadability_p67-averagereadability_p33
gen averagereadability_4555=averagereadability_p55-averagereadability_p45

tabstat averagereadability, statistics( mean median sd min max count cv range ) by(group) columns(statistics)
ttest averagereadability, by(group)
median averagereadability, by(group)
sdtest averagereadability, by(group)
robvar averagereadability, by(group)



tabstat averagereadability_p10 averagereadability_p90 averagereadability_1090 averagereadability_p25 averagereadability_p75 averagereadability_2575 averagereadability_p33 averagereadability_p67 averagereadability_3367 averagereadability_p45 averagereadability_p55 averagereadability_4555, statistics( mean ) by(group) columns(variables)

drop(averagereadability_1090 averagereadability_2575 averagereadability_3367 averagereadability_4555)


** Generate condensed readabilility Scatter Plots with 3rd quintile and inter quartile ranges
twoway (scatter averagereadability proxyplot, mcolor(gs12) msize(small)) (rarea averagereadability_p40 averagereadability_p60 proxyplot, fcolor(none) lcolor(black) lwidth(medium) cmissing(n)) (rarea averagereadability_p25 averagereadability_p75 proxyplot, fcolor(none) lcolor(gs9) lwidth(medium) lpattern(dash) cmissing(y)), ytitle(Average Readability Score) ytitle(, orientation(vertical) margin(small)) ylabel(, labsize(small) angle(horizontal)) xtitle(Proxy Date (group two condensed)) xtitle(, margin(medsmall)) xlabel(#5, labsize(small)) legend(off)
tabstat averagereadability, statistics( mean median sd min max count cv range ) by(group) columns(statistics)


*generate early_late variable and check for early_late effects
gen early_late=.
replace early_late=1 if group==2 & Prox_Mo=="May" & Prox_Day<15
replace early_late=0 if group==2 & early_late==.
label define Yes 0 "No"
label define Yes 1 "Yes", add
label values early_late Yes

tabstat averagereadability, statistics( mean median sd min max count cv range ) by(early_late) columns(statistics)



histogram averagereadability, width(1) start(10) percent fcolor(ltbluishgray) lcolor(blue) ylabel(, angle(horizontal) format(%9.0g)) xlabel(10(2)20) by(group, cols(1) iyaxes ixaxes ixtick ixlabel) legend(off)


******* TABLES, HOW TO START AND PEER LIST FIGURES AND MODELS


*tables histogram

histogram tables, width(1) start(0) percent fcolor(ltbluishgray) lcolor(blue) ylabel(, angle(horizontal) format(%9.0g)) xlabel(0(1)15) by(group, cols(1) iyaxes ixaxes ixtick ixlabel)

** Test for Distributional Differences. (in text in discussion of "tables" findings)

**First - Condense the Tables variable by creating a "five and above" category - then tabulate with Chi^2

gen tables3=tables
replace tables3=5 if tables>4
replace tables3=. if tables==.
tabulate tables3 group, col chi2



** Generate Figure for First Section Analysis (Appendix)

replace first_section_substance_ii = "Compensation Committee" if  first_section_substance_ii == "Committee"
catplot first_section_substance_ii, recast(bar) by(group, cols(1)) percent(group) var1opts(sort(1) descending)



******** MODELS FOR TABLES (NEG BINOMIAL AND PROBIT FOR "NO TABLES") AND HOW TO START 




** Negative Binomial - tables dispersion is about 3x mean (models with no controls, industry and consultants, industry and consultants and market cap)

xi: nbreg tables i.group
prvalue, x(_Igroup_2==0) save
prvalue, x(_Igroup_2==1) diff



xi: nbreg tables i.group i.consul_small i.twodig_sic2

prvalue, x(_Igroup_2==0) save
prvalue, x(_Igroup_2==1) diff


xi: nbreg tables i.group i.consul_small i.twodig_sic2 log_cap

prvalue, x(_Igroup_2==0) save
prvalue, x(_Igroup_2==1) diff




**probit for zero tables (models with no controls, industry and consultants, industry and consultants and market cap)


** creates the  no_tabs2 variable which is a dummy for including tables but codes reports for which a peer list was the only table as 0s since peer list is a separate variable

gen tables2 = tables
replace tables2=tables2-1 if list_in_table=="Yes"
tab tables2 group

gen no_tabs = 0 
replace no_tabs = 1 if tables==0
replace no_tabs = . if tables==.

gen no_tabs2 = 0 
replace no_tabs2 = 1 if tables2==0
replace no_tabs2 = . if tables2==.



xi: probit no_tabs2 i.group
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff

xi: probit no_tabs2 i.group i.consul_small i.twodig_sic2
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff


xi: probit no_tabs2 i.group i.consul_small i.twodig_sic2 log_cap
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff



*** probit models for starting with Overview

gen overview_start=0
replace overview_start=1 if first_section_substance=="Overview"
replace overview_start=. if first_section_substance==""


xi: probit overview_start i.group
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff

xi: probit overview_start i.group i.consul_small i.twodig_sic2
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff

xi: probit overview_start i.group i.consul_small i.twodig_sic2 log_cap
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff


** Analysis for including a list of peers 

replace benchmarkinglist="no" if benchmarkinglist=="No"
replace benchmarkinglist="yes" if benchmarkinglist=="Yes"

gen bmark= 0
replace bmark=1 if benchmarkinglist=="yes"
replace bmark=. if benchmarkinglist==""

**Crosstab
tab bmark group, col chi


** Probit Models for Peer List

xi: probit bmark i.group
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff

xi: probit bmark i.group i.consul_small i.twodig_sic2
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff

xi: probit bmark i.group i.consul_small i.twodig_sic2 log_cap
prvalue if e(sample), x(_Igroup_2==0) save
prvalue if e(sample), x(_Igroup_2==1) diff



** CORRELATED POLICIES ANALYS

***** FOR THE TOP HALF OF THE TABLE

** FIRST - CALCULATE THE INDEPENDENT PROPENSITIES FOR NO TABLES, OVERVIEW START, AND BMARK
tab no_tabs2 group, col
tab overview_start group, col
tab bmark group, col

** CALCULATE THE ACTUAL INCIDENCES OF PAIRINGS (E.G. START WITH OVERVIEW AND PEER LIST) BY GROUP


by group, sort : tab2 no_tabs2 bmark overview_start, cell


*FOR THE BOTTOM PART OF THE TABLE - REGRESSION FOR EACH GROUP and predicted changes for Group 2

xi: probit bmark no_tabs2 overview_start i.consul_small i.twodig_sic2 log_cap if group==1


xi: probit bmark no_tabs2 overview_start i.consul_small i.twodig_sic2 log_cap if group==2
prvalue if e(sample), x(no_tabs2==0) save
prvalue if e(sample), x(no_tabs2==1) diff

prvalue if e(sample), x(overview_start==0) save
prvalue if e(sample), x(overview_start==1) diff







